@@ -129,10 +129,18 @@ def tests(session):
         session.install(COVERAGE_VERSION_REQUIREMENT, silent=PIP_INSTALL_SILENT)
         pytest_version_requirement = os.environ.get("PYTEST_VERSION_REQUIREMENT") or None
         if pytest_version_requirement:
+            # Account that, under CI, when we test previous version of pytest
+            # we need to pin pytest-subtests to a lower version so that pytest
+            # itself does not get upgraded
+            pytest_requirements = []
             if not pytest_version_requirement.startswith("pytest"):
                 pytest_version_requirement = "pytest{}".format(pytest_version_requirement)
-            session.install(pytest_version_requirement, silent=PIP_INSTALL_SILENT)
+            pytest_requirements.append(pytest_version_requirement)
+            if pytest_version_requirement.startswith("pytest~=6"):
+                pytest_requirements.append("pytest-subtests<0.7.0")
+            session.install(*pytest_requirements, silent=PIP_INSTALL_SILENT)
         session.install("-e", ".", silent=PIP_INSTALL_SILENT)
+        session.install("-r", os.path.join("requirements", "base.txt"), silent=PIP_INSTALL_SILENT)
         session.install("-r", os.path.join("requirements", "tests.txt"), silent=PIP_INSTALL_SILENT)
 
         if EXTRA_REQUIREMENTS_INSTALL:
@@ -145,6 +153,13 @@ def tests(session):
             install_command += [req.strip() for req in EXTRA_REQUIREMENTS_INSTALL.split()]
             session.install(*install_command, silent=PIP_INSTALL_SILENT)
 
+    if IS_WINDOWS:
+        _python_version = python_version(session)
+        if _python_version > (3, 8) and _python_version < (3, 10):
+            # We skip a lot of tests, so lower the expected code coverage
+            global COVERAGE_FAIL_UNDER_PERCENT
+            COVERAGE_FAIL_UNDER_PERCENT = 50
+
     session.run("coverage", "erase")
     env.update(
         {
